puzzlepiece module
==================

The main module contains convenience references to the :class:`puzzlepiece.puzzle.Puzzle` and :class:`puzzlepiece.piece.Piece` objects,
so they can be directly referenced as `puzzlepiece.Puzzle` and `puzzlepiece.Piece`.

Importing it also gives direct access to:
  * :mod:`puzzlepiece.param`
  * :mod:`puzzlepiece.action`
  * :mod:`puzzlepiece.parse`
  * :mod:`puzzlepiece.threads`